"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAnimationAPI = exports.mergeStylesFunctions = void 0;

var _react = require("react");

var _reactNativeReanimated = require("react-native-reanimated");

var _useDrag = require("./useDrag");

var _NotificationEmitter = require("../services/NotificationEmitter");

var _animation = require("../utils/animation");

var _animations = require("../../types/animations");

var _useTimer = require("./useTimer");

const mergeStylesObjects = (styles, newStyles) => {
  'worklet';

  const oldTransform = [...((styles === null || styles === void 0 ? void 0 : styles.transform) || [])];
  const newTransform = [...((newStyles === null || newStyles === void 0 ? void 0 : newStyles.transform) || [])];
  return { ...styles,
    ...newStyles,
    transform: [...oldTransform, ...newTransform]
  };
};

const mergeStylesFunctions = (stylesFunctions, progress) => {
  'worklet';

  return stylesFunctions.reduce((accumulatedStyles, styleFunction) => {
    return mergeStylesObjects(accumulatedStyles, styleFunction(progress));
  }, {
    opacity: 1,
    transform: [{
      translateY: 0
    }, {
      translateX: 0
    }]
  } // it has to have the default opacity value
  );
};

exports.mergeStylesFunctions = mergeStylesFunctions;

const useAnimationAPI = _ref => {
  let {
    gestureConfig,
    animationConfig,
    duration,
    onClose
  } = _ref;
  const progress = (0, _reactNativeReanimated.useSharedValue)(0);
  const {
    resetTimer,
    clearTimer
  } = (0, _useTimer.useTimer)();
  const animationInConfig = animationConfig.animationConfigIn;
  const animationOutConfig = animationConfig === null || animationConfig === void 0 ? void 0 : animationConfig.animationConfigOut;
  const {
    dragStateHandler,
    resetDrag,
    ...dragConfig
  } = (0, _useDrag.useDrag)(gestureConfig);
  const currentTransitionType = (0, _reactNativeReanimated.useSharedValue)('in');
  const dismiss = (0, _react.useCallback)(id => {
    currentTransitionType.value = 'out';
    clearTimer();
    resetDrag();
    const dismissConfig = animationOutConfig || animationInConfig;
    const animateWith = dismissConfig.type === 'spring' ? _reactNativeReanimated.withSpring : _reactNativeReanimated.withTiming;

    const handleSuccess = () => {
      currentTransitionType.value = 'in';

      _NotificationEmitter.emitter.emit('pop_notification', id);

      onClose === null || onClose === void 0 ? void 0 : onClose();
    };

    const handleError = () => {};

    progress.value = animateWith(_animations.AnimationRange.END, dismissConfig.config, (0, _animation.withAnimationCallbackJSThread)(handleSuccess, handleError));
  }, [currentTransitionType, clearTimer, resetDrag, animationOutConfig, animationInConfig, progress, onClose]);
  const present = (0, _react.useCallback)(() => {
    currentTransitionType.value = 'in';
    const animateWith = animationInConfig.type === 'spring' ? _reactNativeReanimated.withSpring : _reactNativeReanimated.withTiming;

    const handleSuccess = () => {
      currentTransitionType.value = 'idle_active';
      resetTimer(dismiss, duration);
    };

    const handleError = () => {};

    progress.value = animateWith(_animations.AnimationRange.START, animationInConfig.config, (0, _animation.withAnimationCallbackJSThread)(handleSuccess, handleError));
  }, [animationInConfig, currentTransitionType, dismiss, duration, progress, resetTimer]);
  const cancelTransitionAnimation = (0, _react.useCallback)(() => {
    clearTimer();
    (0, _reactNativeReanimated.cancelAnimation)(progress);
  }, [clearTimer, progress]); // Used to revoke transition (progress) value after canceling it with e.g. LongPressGestureHandler

  const revokeTransitionAnimation = (0, _react.useCallback)(() => {
    switch (currentTransitionType.value) {
      case 'out':
        return dismiss();

      case 'in':
      case 'idle_active':
        return resetTimer(dismiss, duration);
    }
  }, [currentTransitionType.value, dismiss, resetTimer, duration]);
  const handleDragStateChange = dragStateHandler(dismiss, resetDrag);
  const {
    transitionInStyles,
    transitionOutStyles,
    transitionInStylesQueue,
    transitionOutStylesQueue
  } = animationConfig;
  const animatedStyles = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    if (['out', 'idle_active'].includes(currentTransitionType.value) && (transitionOutStylesQueue === null || transitionOutStylesQueue === void 0 ? void 0 : transitionOutStylesQueue.length) > 0) {
      return mergeStylesFunctions(transitionOutStylesQueue, progress);
    }

    if ((transitionInStylesQueue === null || transitionInStylesQueue === void 0 ? void 0 : transitionInStylesQueue.length) > 0) {
      return mergeStylesFunctions(transitionInStylesQueue, progress);
    }

    if (['out', 'idle_active'].includes(currentTransitionType.value) && transitionOutStyles) {
      return {
        opacity: 1,
        ...transitionOutStyles(progress)
      };
    }

    return {
      opacity: 1,
      ...transitionInStyles(progress)
    };
  });
  return { ...dragConfig,
    present,
    dismiss,
    animatedStyles,
    handleDragStateChange,
    cancelTransitionAnimation,
    revokeTransitionAnimation
  };
};

exports.useAnimationAPI = useAnimationAPI;
//# sourceMappingURL=useAnimationAPI.js.map