"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDrag = void 0;

var _react = require("react");

var _reactNativeGestureHandler = require("react-native-gesture-handler");

var _reactNativeReanimated = require("react-native-reanimated");

var _shouldTriggerGesture = require("../gestures/shouldTriggerGesture");

const useDrag = config => {
  const x = (0, _reactNativeReanimated.useSharedValue)(0);
  const y = (0, _reactNativeReanimated.useSharedValue)(0);
  const directions = getDragDirections(config.direction);
  const resetDrag = (0, _react.useCallback)(() => {
    x.value = (0, _reactNativeReanimated.withSpring)(0, {
      mass: 0.2
    });
    y.value = (0, _reactNativeReanimated.withSpring)(0, {
      mass: 0.2
    });
  }, [x, y]);
  const dragGestureHandler = (0, _reactNativeReanimated.useAnimatedGestureHandler)({
    onStart: (_, ctx) => {
      ctx.x = x.value;
      ctx.y = y.value;
    },
    onActive: (_ref, ctx) => {
      let {
        translationX,
        translationY
      } = _ref;
      x.value = ctx.x + translationX * directions.x;
      y.value = ctx.y + translationY * directions.y;
    },
    onEnd: () => {
      x.value = (0, _reactNativeReanimated.withSpring)(0, {
        mass: 0.2
      });
      y.value = (0, _reactNativeReanimated.withSpring)(0, {
        mass: 0.2
      });
    }
  });
  const dragStateHandler = (0, _react.useCallback)((onDragSuccess, onDragFail) => event => {
    const {
      nativeEvent
    } = event;
    if (nativeEvent.state !== _reactNativeGestureHandler.State.END) return event;
    const dragTriggered = (0, _shouldTriggerGesture.shouldTriggerGesture)(config, {
      distance: [nativeEvent.translationX, nativeEvent.translationY],
      velocity: [nativeEvent.velocityX, nativeEvent.velocityY]
    });
    if (dragTriggered) onDragSuccess();else onDragFail();
    return event;
  }, [config]);
  const dragStyles = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    transform: [{
      translateX: x.value
    }, {
      translateY: y.value
    }]
  }));
  return {
    dragGestureHandler,
    dragStateHandler,
    dragStyles,
    resetDrag
  };
};

exports.useDrag = useDrag;

const getDragDirections = direction => {
  switch (direction) {
    case 'full':
      return {
        x: 1,
        y: 1
      };

    case 'x':
      return {
        x: 1,
        y: 0
      };

    case 'y':
      return {
        x: 0,
        y: 1
      };

    case 'none':
      return {
        x: 0,
        y: 0
      };
    // What should be correct default value? => Platform specific?

    default:
      return {
        x: 0,
        y: 0
      };
  }
};
//# sourceMappingURL=useDrag.js.map