"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.emitter = exports.createNotificationsEmitter = void 0;

const createNotificationsEmitter = () => {
  const listeners = new Set();

  const removeListener = listener => {
    listeners.delete(listener);
  };

  const addListener = (eventType, callback) => {
    const listener = {
      eventType,
      callback
    };
    listeners.add(listener);
    return () => removeListener(listener);
  };

  const removeEvent = eventType => {
    const listenersValues = listeners.values();
    listeners.clear();

    for (const value of listenersValues) {
      if (value.eventType !== eventType) {
        listeners.add(value);
      }
    }
  };

  const emit = (eventType, payload) => {
    listeners.forEach(listener => listener.eventType === eventType && listener.callback(payload));
  };

  return {
    addListener,
    removeEvent,
    emit
  };
};

exports.createNotificationsEmitter = createNotificationsEmitter;
const emitter = createNotificationsEmitter();
exports.emitter = emitter;
//# sourceMappingURL=NotificationEmitter.js.map