"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateAnimationConfig = exports.ZoomInZoomOut = exports.ZoomInDownZoomOutUp = exports.ZoomInDownZoomOutDown = exports.VeryCustomTransition = exports.SlideInLeftSlideOutRight = exports.SlideInLeftAnimation = exports.SlideInLeft = exports.RotateZInAnimation = exports.RotateZIn = exports.RotateInRotateOut = exports.MoveUpAnimation = exports.MoveUp = exports.MoveDownAnimation = exports.MoveDown = exports.FadeInFadeOut = exports.DiagonalSlideInLeftSlideOutRight = exports.CrazyAnimationConfigAnimation = exports.CrazyAnimationConfig = exports.AnimationBuilder = void 0;

var _reactNativeReanimated = require("react-native-reanimated");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class AnimationBuilder {
  // stores stacked styles functions after merging animation configs
  // stores stacked styles functions after merging animation configs
  // helper field for handling style funcs merging
  // helper field for handling style funcs merging
  constructor(config) {
    var _this$transitionOutSt;

    _defineProperty(this, "animationConfigIn", void 0);

    _defineProperty(this, "animationConfigOut", void 0);

    _defineProperty(this, "transitionInStylesQueue", []);

    _defineProperty(this, "transitionOutStylesQueue", []);

    _defineProperty(this, "transitionInStyles", void 0);

    _defineProperty(this, "transitionOutStyles", void 0);

    this.transitionInStylesQueue = [];
    this.transitionOutStylesQueue = [];
    this.animationConfigIn = config.animationConfigIn;
    this.animationConfigOut = config.animationConfigOut;
    this.transitionInStyles = config.transitionInStyles;

    if (config.transitionOutStyles) {
      this.transitionOutStyles = config.transitionOutStyles;
    }

    this.transitionInStylesQueue.push(config.transitionInStyles);
    config.transitionOutStyles && ((_this$transitionOutSt = this.transitionOutStylesQueue) === null || _this$transitionOutSt === void 0 ? void 0 : _this$transitionOutSt.push(config.transitionOutStyles));
  }

  add(configToPipe) {
    var _this$transitionOutSt2;

    this.animationConfigIn = configToPipe.animationConfigIn;

    if (configToPipe.animationConfigOut) {
      this.animationConfigOut = configToPipe.animationConfigOut;
    }

    this.transitionInStyles = configToPipe.transitionInStyles;

    if (configToPipe.transitionOutStyles) {
      this.transitionOutStyles = configToPipe.transitionOutStyles;
    }

    this.transitionInStylesQueue.push(configToPipe.transitionInStyles);
    configToPipe.transitionOutStyles && ((_this$transitionOutSt2 = this.transitionOutStylesQueue) === null || _this$transitionOutSt2 === void 0 ? void 0 : _this$transitionOutSt2.push(configToPipe.transitionOutStyles));
    return this;
  }

}

exports.AnimationBuilder = AnimationBuilder;
const ZoomInAnimation = {
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 1000
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const scale = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [0.8, 1]);
    return {
      transform: [{
        scale
      }]
    };
  }
};
const MoveDownAnimation = {
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 400
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      opacity: progress.value,
      transform: [{
        translateY
      }]
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [100, 0]);
    return {
      opacity: progress.value,
      transform: [{
        translateY
      }]
    };
  }
};
exports.MoveDownAnimation = MoveDownAnimation;
const MoveUpAnimation = {
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 400
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      opacity: progress.value,
      transform: [{
        translateY
      }]
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      transform: [{
        translateY
      }]
    };
  }
};
exports.MoveUpAnimation = MoveUpAnimation;
const RotateInAnimation = {
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 700,
      easing: _reactNativeReanimated.Easing.out(_reactNativeReanimated.Easing.exp)
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const rotate = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-360, 0]);
    return {
      transform: [{
        rotate: `${rotate}deg`
      }, {
        scale: progress.value
      }],
      opacity: progress.value
    };
  }
};
const RotateZInAnimation = {
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 2000,
      easing: _reactNativeReanimated.Easing.out(_reactNativeReanimated.Easing.exp)
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const rotateZ = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-140, 0]);
    const rotateX = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [200, 20]);
    const rotateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-40, 5]);
    return {
      transform: [{
        rotateZ: `${rotateZ}deg`
      }, {
        rotateX: `${rotateX}deg`
      }, {
        rotateY: `${rotateY}deg`
      }, {
        scale: progress.value
      }, {
        perspective: 1500
      }],
      opacity: progress.value
    };
  }
};
exports.RotateZInAnimation = RotateZInAnimation;
const SlideInLeftAnimation = {
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 400,
      easing: _reactNativeReanimated.Easing.inOut(_reactNativeReanimated.Easing.sin)
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const translateX = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      transform: [{
        translateX
      }]
    };
  }
};
exports.SlideInLeftAnimation = SlideInLeftAnimation;
const SlideInLeftSlideOutRightAnimation = {
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 400,
      easing: _reactNativeReanimated.Easing.inOut(_reactNativeReanimated.Easing.sin)
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const translateX = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      opacity: progress.value,
      transform: [{
        translateX
      }]
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const translateX = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [100, 0]);
    return {
      opacity: progress.value,
      transform: [{
        translateX
      }]
    };
  }
};
const FadeInAnimation = {
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 500
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const translateX = 0;
    return {
      opacity: progress.value,
      transform: [{
        translateX
      }]
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const translateX = 0;
    return {
      opacity: progress.value,
      transform: [{
        translateX
      }]
    };
  }
};
const CrazyAnimationConfigAnimation = {
  animationConfigIn: {
    type: 'spring',
    config: {
      damping: 10,
      velocity: 20,
      stiffness: 80,
      mass: 1.2
    }
  },
  animationConfigOut: {
    type: 'timing',
    config: {
      duration: 200
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const interpolatedTrans = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [0, 100]);
    return {
      transform: [{
        translateY: 500
      }, {
        translateX: interpolatedTrans
      }],
      opacity: progress.value
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const interpolatedTrans = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [0, 500]);
    return {
      transform: [{
        translateY: interpolatedTrans
      }],
      opacity: progress.value
    };
  }
};
exports.CrazyAnimationConfigAnimation = CrazyAnimationConfigAnimation;
const VeryCustomTransitionAnimation = {
  animationConfigIn: {
    type: 'spring',
    config: {
      damping: 10,
      velocity: 20,
      stiffness: 80,
      mass: 1.2
    }
  },
  animationConfigOut: {
    type: 'timing',
    config: {
      duration: 200
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [0, 100]);
    return {
      transform: [{
        translateY
      }],
      opacity: progress.value
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [500, 100]);
    return {
      transform: [{
        translateY
      }],
      opacity: progress.value
    };
  }
};
const DiagonalSlideInLeftSlideOutRightAnimation = {
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 700
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const translateX = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      transform: [{
        translateX
      }, {
        translateY
      }],
      opacity: progress.value
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const translateX = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [100, 0]);
    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      transform: [{
        translateX
      }, {
        translateY
      }],
      opacity: progress.value
    };
  }
};
const MoveDown = new AnimationBuilder(MoveDownAnimation);
exports.MoveDown = MoveDown;
const MoveUp = new AnimationBuilder(MoveUpAnimation);
exports.MoveUp = MoveUp;
const ZoomInZoomOut = new AnimationBuilder(ZoomInAnimation);
exports.ZoomInZoomOut = ZoomInZoomOut;
const SlideInLeft = new AnimationBuilder(SlideInLeftAnimation);
exports.SlideInLeft = SlideInLeft;
const SlideInLeftSlideOutRight = new AnimationBuilder(SlideInLeftSlideOutRightAnimation);
exports.SlideInLeftSlideOutRight = SlideInLeftSlideOutRight;
const RotateInRotateOut = new AnimationBuilder(RotateInAnimation);
exports.RotateInRotateOut = RotateInRotateOut;
const RotateZIn = new AnimationBuilder(RotateZInAnimation);
exports.RotateZIn = RotateZIn;
const FadeInFadeOut = new AnimationBuilder(FadeInAnimation);
exports.FadeInFadeOut = FadeInFadeOut;
const CrazyAnimationConfig = new AnimationBuilder(CrazyAnimationConfigAnimation);
exports.CrazyAnimationConfig = CrazyAnimationConfig;
const VeryCustomTransition = new AnimationBuilder(VeryCustomTransitionAnimation);
exports.VeryCustomTransition = VeryCustomTransition;
const DiagonalSlideInLeftSlideOutRight = new AnimationBuilder(DiagonalSlideInLeftSlideOutRightAnimation);
exports.DiagonalSlideInLeftSlideOutRight = DiagonalSlideInLeftSlideOutRight;
const ZoomInDownZoomOutDown = new AnimationBuilder(ZoomInAnimation).add(MoveDown);
exports.ZoomInDownZoomOutDown = ZoomInDownZoomOutDown;
const ZoomInDownZoomOutUp = new AnimationBuilder(ZoomInZoomOut).add(MoveUp);
/**
 * @deprecated since version > 0.0.1-beta.2
 */

exports.ZoomInDownZoomOutUp = ZoomInDownZoomOutUp;

const generateAnimationConfig = config => {
  return config;
};

exports.generateAnimationConfig = generateAnimationConfig;
//# sourceMappingURL=generateAnimationConfig.js.map