"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.queueReducer = void 0;

const queueReducer = (state, action) => {
  switch (action.type) {
    case 'modify':
      return modify(state, action);

    case 'pop':
      return pop(state, action);

    case 'add':
      return add(state, action);

    case 'remove':
      return remove(state, action);

    default:
      return state;
  }
};

exports.queueReducer = queueReducer;

const add = (state, action) => {
  return [...state, action.payload];
};

const pop = (state, action) => {
  if (action.payload) {
    return state.filter(notification => notification.id !== action.payload);
  }

  return state.filter((_, index) => index !== 0);
};

const remove = (state, action) => {
  var _state$;

  // fallback to exit animation when notification to remove is active
  if ((_state$ = state[0]) !== null && _state$ !== void 0 && _state$.id && state[0].id === action.payload) {
    action.onActiveNotification(action.payload);
    return state;
  }

  return state.filter(el => el.id !== action.payload);
};

const modify = (state, action) => {
  return state.map(notification => {
    if (notification.id !== action.payload.id) return notification;
    return { ...notification,
      params: { ...notification.params,
        ...action.payload.params
      }
    };
  });
};
//# sourceMappingURL=queueReducer.js.map