"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NotificationBase = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _stylesUtils = require("../stylesUtils");

var _styles = require("../styles");

var _reactNativeGestureHandler = require("react-native-gesture-handler");

var _reactNativeNotificated = require("react-native-notificated");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const NotificationBase = props => {
  const containerStyles = (0, _stylesUtils.getContainerStyles)({ ...props
  });
  const titleStyle = (0, _stylesUtils.getTitleStyle)({ ...props
  });
  const descriptionStyle = (0, _stylesUtils.getDescriptionStyle)({ ...props
  });
  const accentStyle = (0, _stylesUtils.getLeftAccentStyle)(props.accentColor);
  const rightIconSource = props.theme === 'regular' ? require('../../assets/images/close-regularMode.png') : require('../../assets/images/close-darkMode.png');
  const {
    remove
  } = (0, _reactNativeNotificated.useNotificationController)();

  const renderLeftIcon = () => typeof props.leftIconSource === 'object' ? props.leftIconSource : /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: props.leftIconSource,
    style: { ..._styles.styles.icon,
      ...(props === null || props === void 0 ? void 0 : props.imageStyle)
    }
  });

  const renderRightIcon = () => !props.hideCloseButton && /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.TouchableOpacity, {
    onPress: () => {
      remove();
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: rightIconSource,
    style: _styles.styles.icon
  }));

  const renderTitle = () => /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: titleStyle
  }, props.title);

  const renderDescription = () => {
    var _props$multiline;

    return !!props.description && /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: descriptionStyle,
      numberOfLines: (_props$multiline = props.multiline) !== null && _props$multiline !== void 0 ? _props$multiline : 1
    }, props.description);
  };

  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: (0, _stylesUtils.constShadow)(props.theme, props.borderRadius)
  }, /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.TouchableWithoutFeedback, {
    onPress: () => {
      var _props$onPress;

      return (_props$onPress = props.onPress) === null || _props$onPress === void 0 ? void 0 : _props$onPress.call(props);
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: containerStyles
  }, props.borderType === 'accent' && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: accentStyle
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.content
  }, props.defaultIconType !== 'no-icon' && renderLeftIcon(), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.textWrapper
  }, renderTitle(), renderDescription()), renderRightIcon()))));
};

exports.NotificationBase = NotificationBase;
//# sourceMappingURL=notificationBase.js.map