"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ZoomInDownZoomOutUp = exports.ZoomInDownZoomOutDown = exports.VeryCustomTransition = exports.SlideInLeftSlideOutRight = exports.RotateZIn = exports.RotateInRotateOut = exports.FadeInFadeOut = exports.DiagonalSlideInLeftSlideOutRight = exports.CrazyAnimationConfig = void 0;

var _reactNativeReanimated = require("react-native-reanimated");

var _generateAnimationConfig = require("../core/utils/generateAnimationConfig");

const ZoomInDownZoomOutUp = (0, _generateAnimationConfig.generateAnimationConfig)({
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 400,
      easing: _reactNativeReanimated.Easing.inOut(_reactNativeReanimated.Easing.sin)
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const scale = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [0.8, 1]);
    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      opacity: progress.value,
      transform: [{
        scale
      }, {
        translateY
      }]
    };
  }
});
exports.ZoomInDownZoomOutUp = ZoomInDownZoomOutUp;
const ZoomInDownZoomOutDown = (0, _generateAnimationConfig.generateAnimationConfig)({
  animationConfigIn: {
    type: 'spring',
    config: {
      damping: 4,
      mass: 0.8
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const scale = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [0.8, 1]);
    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      opacity: progress.value,
      transform: [{
        scale
      }, {
        translateY
      }]
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const scale = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [0.8, 1]);
    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [100, 0]);
    return {
      opacity: progress.value,
      transform: [{
        scale
      }, {
        translateY
      }]
    };
  }
});
exports.ZoomInDownZoomOutDown = ZoomInDownZoomOutDown;
const RotateInRotateOut = (0, _generateAnimationConfig.generateAnimationConfig)({
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 700,
      easing: _reactNativeReanimated.Easing.out(_reactNativeReanimated.Easing.exp)
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const rotate = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-360, 0]);
    return {
      transform: [{
        rotate: `${rotate}deg`
      }, {
        scale: progress.value
      }],
      opacity: progress.value
    };
  }
});
exports.RotateInRotateOut = RotateInRotateOut;
const RotateZIn = (0, _generateAnimationConfig.generateAnimationConfig)({
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 2000,
      easing: _reactNativeReanimated.Easing.out(_reactNativeReanimated.Easing.exp)
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const rotateZ = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-140, 0]);
    const rotateX = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [200, 20]);
    const rotateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-40, 5]);
    return {
      transform: [{
        rotateZ: `${rotateZ}deg`
      }, {
        rotateX: `${rotateX}deg`
      }, {
        rotateY: `${rotateY}deg`
      }, {
        scale: progress.value
      }, {
        perspective: 1500
      }],
      opacity: progress.value
    };
  }
});
exports.RotateZIn = RotateZIn;
const SlideInLeftSlideOutRight = (0, _generateAnimationConfig.generateAnimationConfig)({
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 400,
      easing: _reactNativeReanimated.Easing.inOut(_reactNativeReanimated.Easing.sin)
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const translateX = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      opacity: progress.value,
      transform: [{
        translateX
      }]
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const translateX = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [100, 0]);
    return {
      opacity: progress.value,
      transform: [{
        translateX
      }]
    };
  }
});
exports.SlideInLeftSlideOutRight = SlideInLeftSlideOutRight;
const CrazyAnimationConfig = (0, _generateAnimationConfig.generateAnimationConfig)({
  animationConfigIn: {
    type: 'spring',
    config: {
      damping: 10,
      velocity: 20,
      stiffness: 80,
      mass: 1.2
    }
  },
  animationConfigOut: {
    type: 'timing',
    config: {
      duration: 200
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const interpolatedTrans = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [0, 100]);
    return {
      transform: [{
        translateY: 500
      }, {
        translateX: interpolatedTrans
      }],
      opacity: progress.value
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const interpolatedTrans = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [0, 500]);
    return {
      transform: [{
        translateY: interpolatedTrans
      }],
      opacity: progress.value
    };
  }
});
exports.CrazyAnimationConfig = CrazyAnimationConfig;
const VeryCustomTransition = (0, _generateAnimationConfig.generateAnimationConfig)({
  animationConfigIn: {
    type: 'spring',
    config: {
      damping: 10,
      velocity: 20,
      stiffness: 80,
      mass: 1.2
    }
  },
  animationConfigOut: {
    type: 'timing',
    config: {
      duration: 200
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [0, 100]);
    return {
      transform: [{
        translateY
      }],
      opacity: progress.value
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [500, 100]);
    return {
      transform: [{
        translateY
      }],
      opacity: progress.value
    };
  }
});
exports.VeryCustomTransition = VeryCustomTransition;
const DiagonalSlideInLeftSlideOutRight = (0, _generateAnimationConfig.generateAnimationConfig)({
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 700
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const translateX = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      transform: [{
        translateX
      }, {
        translateY
      }],
      opacity: progress.value
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const translateX = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [100, 0]);
    const translateY = (0, _reactNativeReanimated.interpolate)(progress.value, [0, 1], [-100, 0]);
    return {
      transform: [{
        translateX
      }, {
        translateY
      }],
      opacity: progress.value
    };
  }
});
exports.DiagonalSlideInLeftSlideOutRight = DiagonalSlideInLeftSlideOutRight;
const FadeInFadeOut = (0, _generateAnimationConfig.generateAnimationConfig)({
  animationConfigIn: {
    type: 'timing',
    config: {
      duration: 500
    }
  },
  transitionInStyles: progress => {
    'worklet';

    const translateX = 0;
    return {
      opacity: progress.value,
      transform: [{
        translateX
      }]
    };
  },
  transitionOutStyles: progress => {
    'worklet';

    const translateX = 0;
    return {
      opacity: progress.value,
      transform: [{
        translateX
      }]
    };
  }
});
exports.FadeInFadeOut = FadeInFadeOut;
//# sourceMappingURL=defaultAnimationConfig.js.map