"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTitleStyle = exports.getLeftAccentStyle = exports.getDescriptionStyle = exports.getContainerStyles = exports.constShadow = exports.chooseDefaultAccentColor = void 0;

var _reactNative = require("react-native");

var _theme = require("./components/theme");

const getTitleStyle = styles => ({
  color: styles.titleColor ? styles.titleColor : _theme.themeBase.fontColor[styles.theme],
  fontSize: styles.titleSize ? styles.titleSize : _theme.themeBase.fontSize.headerFontSize,
  fontFamily: styles.titleFamily ? styles.titleFamily : undefined,
  fontWeight: styles.titleWeight ? styles.titleWeight : _theme.themeBase.fontWeight.title
});

exports.getTitleStyle = getTitleStyle;

const getDescriptionStyle = styles => ({
  color: styles.descriptionColor ? styles.descriptionColor : _theme.themeBase.fontColor[styles.theme],
  fontSize: styles.descriptionSize ? styles.descriptionSize : _theme.themeBase.fontSize.messageFontSize,
  paddingTop: _theme.themeBase.spacing.xs,
  fontFamily: styles.descriptionFamily ? styles.descriptionFamily : undefined,
  fontWeight: styles.descriptionWeight ? styles.descriptionWeight : _theme.themeBase.fontWeight.description
});

exports.getDescriptionStyle = getDescriptionStyle;

const constShadow = (theme, borderRadius) => {
  const crossPlatformStyle = _reactNative.Platform.select({
    ios: {
      shadowColor: _theme.themeBase.color.shadow,
      shadowOffset: {
        width: 1,
        height: 2
      },
      shadowOpacity: 1,
      shadowRadius: 7
    },
    android: {
      elevation: 5,
      borderBottomWidth: 0,
      borderRadius: borderRadius
    }
  });

  return theme === 'regular' && crossPlatformStyle ? crossPlatformStyle : {};
};

exports.constShadow = constShadow;

const getContainerStyles = styles => {
  var _styles$borderRadius, _styles$bgColor;

  const defaultBackgroundColor = styles.theme ? _theme.themeBase.bgColor[styles.theme] : _theme.themeBase.bgColor.regular;
  return { ...styles,
    display: 'flex',
    flexDirection: 'row',
    justifyContent: 'flex-start',
    alignItems: 'center',
    overflow: 'hidden',
    borderRadius: (_styles$borderRadius = styles.borderRadius) !== null && _styles$borderRadius !== void 0 ? _styles$borderRadius : _theme.themeBase.borderRadius.regular,
    borderWidth: styles.borderType === 'border' ? styles.borderWidth : 0,
    borderColor: styles.accentColor,
    backgroundColor: (_styles$bgColor = styles.bgColor) !== null && _styles$bgColor !== void 0 ? _styles$bgColor : defaultBackgroundColor
  };
};

exports.getContainerStyles = getContainerStyles;

const getLeftAccentStyle = accentColor => {
  return {
    flex: 0.045,
    height: '100%',
    backgroundColor: accentColor !== null && accentColor !== void 0 ? accentColor : ''
  };
};

exports.getLeftAccentStyle = getLeftAccentStyle;

const chooseDefaultAccentColor = notificationType => {
  switch (notificationType) {
    case 'success':
      return _theme.themeBase.color.success;

    case 'error':
      return _theme.themeBase.color.error;

    case 'warning':
      return _theme.themeBase.color.warning;

    case 'info':
      return _theme.themeBase.color.info;
  }
};

exports.chooseDefaultAccentColor = chooseDefaultAccentColor;
//# sourceMappingURL=stylesUtils.js.map