import React from 'react';
import { useWindowDimensions } from 'react-native';
import { PanGestureHandler } from 'react-native-gesture-handler';
import Animated from 'react-native-reanimated';
import { styles } from '../utils/styles';
import { Constants } from '../config';
import { calculateNotificationPositionCoordintates } from '../utils/calculateNotificationPositionCoordintates';
export const GestureHandler = _ref => {
  let {
    children,
    state,
    animationAPI,
    notificationTopPosition
  } = _ref;
  const {
    width
  } = useWindowDimensions();
  const {
    calculatedNotificationWidth,
    top,
    left,
    right
  } = calculateNotificationPositionCoordintates({
    screenWidth: width,
    notificationOffset: state.notificationOffset,
    notificationWidth: state.notificationWidth,
    notificationTopPosition
  });
  return /*#__PURE__*/React.createElement(PanGestureHandler, {
    ref: state.panHandlerRef,
    simultaneousHandlers: state.longPressHandlerRef,
    onGestureEvent: animationAPI.dragGestureHandler,
    onHandlerStateChange: animationAPI.handleDragStateChange
  }, /*#__PURE__*/React.createElement(Animated.View, {
    onLayout: e => state.setNotificationHeight(e.nativeEvent.layout.height),
    style: [animationAPI.dragStyles, styles.container, Constants.isAndroid ? styles.containerAndroid : styles.containerIos, {
      top,
      left,
      right,
      width: calculatedNotificationWidth
    }]
  }, children));
};
//# sourceMappingURL=GestureHandler.js.map