import { Constants } from '../config';
export const getNotificationOffset = _ref => {
  let {
    globalConfig,
    notificationHeight,
    isPortraitMode,
    windowHeight,
    statusBarHeight
  } = _ref;
  const isNotch = globalConfig.isNotch;
  const extraSpace = statusBarHeight + 10;
  const shouldRenderExtraSpace = isNotch !== null && isNotch !== void 0 ? isNotch : isPortraitMode && !Constants.isAndroid;
  const topPosition = shouldRenderExtraSpace ? extraSpace : 10;
  const notificationPosition = globalConfig.notificationPosition;
  let topOffset, leftOffset, rightOffset;

  switch (notificationPosition) {
    case 'top':
      topOffset = topPosition;
      break;

    case 'top-left':
      topOffset = topPosition;
      leftOffset = Constants.notificationSideMargin;
      break;

    case 'top-right':
      topOffset = topPosition;
      rightOffset = Constants.notificationSideMargin;
      break;

    case 'center':
      topOffset = windowHeight / 2 - (notificationHeight ? notificationHeight / 2 + 10 : 75);
      break;

    case 'bottom':
      topOffset = windowHeight - (notificationHeight ? notificationHeight + extraSpace : 150);
      break;

    case 'bottom-left':
      topOffset = windowHeight - (notificationHeight ? notificationHeight + extraSpace : 150);
      leftOffset = Constants.notificationSideMargin;
      break;

    case 'bottom-right':
      topOffset = windowHeight - (notificationHeight ? notificationHeight + extraSpace : 150);
      rightOffset = Constants.notificationSideMargin;
      break;

    default:
      topOffset = topPosition;
      break;
  }

  return {
    top: topOffset,
    left: leftOffset,
    right: rightOffset
  };
};
export const pickVariant = function (config, variantKey) {
  let strict = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  const convertedVariantKey = String(variantKey);
  const variant = config.variants[convertedVariantKey];

  if (!variant && strict) {
    throw Error(`${convertedVariantKey} doesn't exists`);
  }

  return variant;
};

const pickDefaultVariantConfig = (config, variantKey) => {
  const checkIsDefaultConfig = (globalConfig, variant) => {
    var _globalConfig$variant, _globalConfig$variant2, _globalConfig$variant3;

    return Boolean(globalConfig === null || globalConfig === void 0 ? void 0 : (_globalConfig$variant = globalConfig.variants) === null || _globalConfig$variant === void 0 ? void 0 : (_globalConfig$variant2 = _globalConfig$variant[variant]) === null || _globalConfig$variant2 === void 0 ? void 0 : (_globalConfig$variant3 = _globalConfig$variant2.config) === null || _globalConfig$variant3 === void 0 ? void 0 : _globalConfig$variant3.__isDefault);
  };

  if (checkIsDefaultConfig(config, variantKey)) {
    var _config$defaultStyles;

    const variantName = `${variantKey}Config`;
    const defaultConfig = (_config$defaultStyles = config.defaultStylesSettings) === null || _config$defaultStyles === void 0 ? void 0 : _config$defaultStyles[variantName];

    if (defaultConfig !== null && defaultConfig !== void 0 && defaultConfig.notificationPosition) {
      return {
        notificationPosition: defaultConfig.notificationPosition
      };
    }
  }

  return {};
};

export const mergeConfigs = (globalConfig, notificationEvent) => {
  var _pickVariant;

  const name = String(notificationEvent === null || notificationEvent === void 0 ? void 0 : notificationEvent.notificationType);
  const defaultVariantConfig = pickDefaultVariantConfig(globalConfig, name);
  const variantConfig = (_pickVariant = pickVariant(globalConfig, name)) === null || _pickVariant === void 0 ? void 0 : _pickVariant.config;
  return { ...globalConfig,
    ...variantConfig,
    ...defaultVariantConfig,
    ...(notificationEvent === null || notificationEvent === void 0 ? void 0 : notificationEvent.config)
  };
};
//# sourceMappingURL=pickers.js.map