import React from 'react';
import { Image, Text, View } from 'react-native';
import { constShadow, getContainerStyles, getDescriptionStyle, getLeftAccentStyle, getTitleStyle } from '../stylesUtils';
import { styles } from '../styles';
import { TouchableOpacity, TouchableWithoutFeedback } from 'react-native-gesture-handler';
import { useNotificationController } from 'react-native-notificated';
export const NotificationBase = props => {
  const containerStyles = getContainerStyles({ ...props
  });
  const titleStyle = getTitleStyle({ ...props
  });
  const descriptionStyle = getDescriptionStyle({ ...props
  });
  const accentStyle = getLeftAccentStyle(props.accentColor);
  const rightIconSource = props.theme === 'regular' ? require('../../assets/images/close-regularMode.png') : require('../../assets/images/close-darkMode.png');
  const {
    remove
  } = useNotificationController();

  const renderLeftIcon = () => typeof props.leftIconSource === 'object' ? props.leftIconSource : /*#__PURE__*/React.createElement(Image, {
    source: props.leftIconSource,
    style: { ...styles.icon,
      ...(props === null || props === void 0 ? void 0 : props.imageStyle)
    }
  });

  const renderRightIcon = () => !props.hideCloseButton && /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: () => {
      remove();
    }
  }, /*#__PURE__*/React.createElement(Image, {
    source: rightIconSource,
    style: styles.icon
  }));

  const renderTitle = () => /*#__PURE__*/React.createElement(Text, {
    style: titleStyle
  }, props.title);

  const renderDescription = () => {
    var _props$multiline;

    return !!props.description && /*#__PURE__*/React.createElement(Text, {
      style: descriptionStyle,
      numberOfLines: (_props$multiline = props.multiline) !== null && _props$multiline !== void 0 ? _props$multiline : 1
    }, props.description);
  };

  return /*#__PURE__*/React.createElement(View, {
    style: constShadow(props.theme, props.borderRadius)
  }, /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
    onPress: () => {
      var _props$onPress;

      return (_props$onPress = props.onPress) === null || _props$onPress === void 0 ? void 0 : _props$onPress.call(props);
    }
  }, /*#__PURE__*/React.createElement(View, {
    style: containerStyles
  }, props.borderType === 'accent' && /*#__PURE__*/React.createElement(View, {
    style: accentStyle
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.content
  }, props.defaultIconType !== 'no-icon' && renderLeftIcon(), /*#__PURE__*/React.createElement(View, {
    style: styles.textWrapper
  }, renderTitle(), renderDescription()), renderRightIcon()))));
};
//# sourceMappingURL=notificationBase.js.map